==> am_mod_evt_0_5.zip: am_mod_evt_0_5/components/evt/edit.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

if (isset($_SESSION['user_id']) && $core_config['resource']['module']['evt']['create'] & $_SESSION['user_mod_permission']) {
	
	$menu_section = "event";
	include_once ("config/evt.config.php");
	include_once ('inc/evt_initiate.inc.php');
	// get locations
	$output_locations = $user->selLocations($_SESSION['language_id']);
	$body->set('locations', $output_locations);
	$body->set('datedropdown', $date->dateDropdown());

	require_once($language_path_core . 'inc/html_edit.lang.inc.php');
	
	
	if (isset($_REQUEST['event_id'])) {
	
		$output_event['event_start_date'] = date('Y-m-d', strtotime($output_event['event_end_datetime'] . " - " . $output_event['event_duration'] . " hours"));
		$output_event['event_start_time'] =  date('H:i', strtotime($output_event['event_end_datetime'] . " - " . $output_event['event_duration'] . " hours"));
		$output_event['event_duration_type'] = $output_event['event_duration'] >= 24 ? 24 : 1;
		
		if ($output_event['event_duration'] >= 24) {
			$output_event['event_duration'] = round($output_event['event_duration'] / 24);
		}
	
		if (!isset($output_event) || empty($output_event)) {
			header("location: index.php?amn=evt_item&event_id=" . $evt->event_id);
			exit;
		}
	}
	else {
		$output_identities = $user->selUserIdentities($_SESSION['user_id']);
		$body->set('identities', $output_identities);
	}
	
	if (isset($_POST['sub_insert'])) {
		
		if (isset($_POST['event_all_day'])) {
			$_POST['event_duration'] = 24;
			$_POST['event_duration_type'] = 1;
		}
		
		$_POST['event_body'] = kses_parse($_POST['event_body'], 'max');

		if (empty($GLOBALS['am_error_log'])) {
			if (isset($_REQUEST['event_id'])) {
				$event->updateEvent($_POST);
				$event_id = $_REQUEST['event_id'];
			}
			else {
				$event->insertEvent($_POST);
				$event_id = $event->event_id;
				
				if (empty($GLOBALS['am_error_log'])) {
					require_once ('components/core/class/Participation.class.php');
					$participation = new Participation($db, $core_config);
					$participation->module_id = $core_config['module_id']['event'];
					$participation->item_id = $event->event_id;
				
					$user->identity_type = $core_config['user']['identity']['type']['registered'];
				
					$permission = 0;
					foreach($event_config['resource']['user'] as $e) {
						$permission += $e;
					}
					
					$data = array();
					$data['role_id'] = $event_config['role']['coordinator'];
					$data['user_id'] = $_SESSION['user_id'];
					$data['status_id'] = $core_config['participation']['status']['active'];
					$data['identity_id'] = $_POST['identity_id'];
					$data['participation_permission'] = $permission;
				
					$participation->insertParticipant($data);
					
					
					// membership-type
					if ($_POST['participation_type'] == $event_config['type']['membership_type']) {
					
						$query = "
							DELETE FROM " . $db->prefix . "_mem_type_access 
							WHERE 
							module_id=" . $core_config['module_id']['event'] . " AND 
							item_id=" . $event->event_id
						;
					
						if (!empty($_POST['membership_types'])) {
							foreach ($_POST['membership_types'] as $key => $i) :
								$rec = array();
								$rec['module_id'] = $core_config['module_id']['event'];
								$rec['item_id'] = $event->event_id;
								$rec['membership_type_id'] = $i;
								
								$table = $db->prefix . "_mem_type_access";
									
								$query = $db->GetInsertSQL($table, $rec, get_magic_quotes_gpc());
								$result = $db->Execute($query);
							endforeach;
						}
					}
					
					// Count events -----------------------------------
					$query = "
						SELECT COUNT(*) AS total_events
						FROM " . $db->prefix . "_event"
					;
					
					$result = $db->Execute($query);
					if (isset($result->fields)) {
						$total_events = $result->fields['total_events'];
						$result->Close();
					}
					else {
						$error_info = "file=evt_edit.php -- " . $query . " -- " . $this->db->ErrorMsg();
						$GLOBALS['am_error_log'][] = array('db_error', $error_info);
					}
					
					// insert statistics ------------------------------
					require_once('components/core/class/Statistic.class.php');
					$statistic = new Statistic($db, $event_config['statistic']);
					$statistic->module_id = $core_config['module_id']['event'];
					$statistic->item_id = $_SESSION['user_id'];
				
					// insert event statistics
					$statistic->statistic_type_id = $event_config['statistic']['total_events'];
					$statistic->setStatistic($total_events);
				}
			}
		}
		
		if (isset($_FILES['frm_file']) && !empty($_FILES['frm_file'])) {
			include_once('components/core/class/File.class.php');
				
			$file = new File($db, $core_config['file']);
			$file->max_height = $core_config['file']['image']['max_height'];
			$file->max_width = $core_config['file']['image']['max_width'];
			$file->module_id = 0; // there is no file-area for events, therefore we use core.
			$file->core_config_module = $core_config['module'];
			$file->user_id   = $_SESSION['user_id'];
			$file->setFile($_FILES['frm_file']);
					
			if (isset($_POST['frm_file_name']) && !empty($_POST['frm_file_name'])) {
				$file->setSaveName($_POST['frm_file_name']);
			}
			
			if ($file->checkAllocation()) {
				if ($file->checkMimeType()) {
					$file->moveFile();
					$file->createThumbNails();
					$file->insertRecord();
						
					if (isset($file->file_id)) {
						unset ($rec);
						$rec['file_id'] = $file->file_id;
							
						$query = "
							SELECT *
							FROM " . $db->prefix . "_event
							WHERE event_id=" . $event_id
						;
							
						$event_result = $db->Execute($query);
						
						if (isset($event_result->fields)) {
							$query = $db->GetUpdateSQL($event_result, $rec, false, get_magic_quotes_gpc());
							$result = $db->Execute($query);
						}
					}
				}
			}
		}
		
		if (empty($GLOBALS['am_error_log'])) { // everything was ok, send us to next page
		
			header("location: index.php?amn=evt_list&view=my_events");
			exit;
		}
		
		$output_event = $_POST;
		$output_event['event_start_date'] = $_POST['schedule_start_date'];
		$output_event['event_start_time'] = $_POST['schedule_start_time'];
  		$output_event['event_body'] = stripslashes($output_event['event_body']);
		
		if (!empty($_POST['membership_types'])) {
			$output_event['membership_type_ids'] = $_POST['membership_types'];
		}
	}
	elseif (isset($_POST['sub_preview'])) {
		
		$output_event = $_POST;
		$output_event['event_start_date'] = $_POST['schedule_start_date'];
		$output_event['event_start_time'] = $_POST['schedule_start_time'];

		if (!empty($_POST['membership_types'])) {
			$output_event['membership_type_ids'] = $_POST['membership_types'];
		}
		
		$output_event['display_event_body'] = stripslashes(kses_parse($_POST['event_body'], 'max'));

		$output_event['event_body'] = stripslashes($output_event['event_body']);
		$output_event['display_event_body'] = stripslashes($output_event['display_event_body']);
		
		if ($core_config['xhtml_markup']['format']['nl2br'] == 1) {
			$output_event['display_event_body'] = nl2br($output_event['display_event_body']);
		}
		else {
			$output_event['display_event_body'] = $output_event['display_event_body'];
		}
	
		$body->set('event', $output_event);
	}
	else {
		$output_event['location_id'] = $_SESSION['location_id']; // pre-define location
	}
	
	// FILE SETUP
	require_once ("components/core/class/File.class.php");
	$file = new File($db, $core_config['file']);
	$file->user_id = $_SESSION['user_id'];
	$file->module_id = 0; // core
	$file->directory = "core";
	$file->no_image = $core_config['file']['image']['thumb'][2]['no_image'];
	$file->thumbs = $core_config['file']['image']['thumb'];
	
	$images = $file->selFiles("images", "t2");
	$body->set("images", $images);
	
	
	$body->set('event_config', $event_config);
	$body->set('event', $output_event);
}
else {
	header('location: index.php');
	exit;
}
?>

==> am_mod_evt_0_6.zip: am_mod_evt_0_6/components/evt/edit.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

if (isset($_SESSION['user_id']) && $core_config['resource']['module']['evt']['create'] & $_SESSION['user_mod_permission']) {
	
	$menu_section = "event";
	include_once ("config/evt.config.php");
	include_once ('inc/evt_initiate.inc.php');
	// get locations
	$output_locations = $user->selLocations($_SESSION['language_id']);
	$body->set('locations', $output_locations);
	$body->set('datedropdown', $date->dateDropdown());

	require_once($language_path_core . 'inc/html_edit.lang.inc.php');
	
	
	if (isset($_REQUEST['event_id'])) {
	
		$output_event['event_start_date'] = date('Y-m-d', strtotime($output_event['event_end_datetime'] . " - " . $output_event['event_duration'] . " hours"));
		$output_event['event_start_time'] =  date('H:i', strtotime($output_event['event_end_datetime'] . " - " . $output_event['event_duration'] . " hours"));
		$output_event['event_duration_type'] = $output_event['event_duration'] >= 24 ? 24 : 1;
		
		if ($output_event['event_duration'] >= 24) {
			$output_event['event_duration'] = round($output_event['event_duration'] / 24);
		}
	
		if (!isset($output_event) || empty($output_event)) {
			header("location: index.php?amn=evt_item&event_id=" . $evt->event_id);
			exit;
		}
	}
	else {
		$user->identity_allow_usage = 1;
		$output_identities = $user->selUserIdentities($_SESSION['user_id']);
		$body->set('identities', $output_identities);
	}
	
	if (isset($_POST['sub_insert'])) {
		
		if (isset($_POST['event_all_day'])) {
			$_POST['event_duration'] = 24;
			$_POST['event_duration_type'] = 1;
		}
		
		$_POST['event_body'] = kses_parse($_POST['event_body'], 'max');

		if (empty($GLOBALS['am_error_log'])) {
			if (isset($_REQUEST['event_id'])) {
				$event->updateEvent($_POST);
				$event_id = $_REQUEST['event_id'];
			}
			else {
				
				$event->insertEvent($_POST);
				$event_id = $event->event_id;
				
				if (empty($GLOBALS['am_error_log'])) {
					require_once ('components/core/class/Participation.class.php');
					$participation = new Participation($db, $core_config);
					$participation->module_id = $core_config['module_id']['event'];
					$participation->item_id = $event->event_id;
				
					$user->identity_type = $core_config['user']['identity']['type']['registered'];
				
					$permission = 0;
					foreach($event_config['resource']['user'] as $e) {
						$permission += $e;
					}
					
					$data = array();
					$data['role_id'] = $event_config['role']['coordinator'];
					$data['user_id'] = $_SESSION['user_id'];
					$data['status_id'] = $core_config['participation']['status']['active'];
					$data['identity_id'] = $_POST['identity_id'];
					$data['participation_permission'] = $permission;
				
					$participation->insertParticipant($data);
					
					
					// membership-type
					if ($_POST['participation_type'] == $event_config['type']['membership_type']) {
					
						$query = "
							DELETE FROM " . $db->prefix . "_mem_type_access 
							WHERE 
							module_id=" . $core_config['module_id']['event'] . " AND 
							item_id=" . $event->event_id
						;
					
						if (!empty($_POST['membership_types'])) {
							foreach ($_POST['membership_types'] as $key => $i) :
								$rec = array();
								$rec['module_id'] = $core_config['module_id']['event'];
								$rec['item_id'] = $event->event_id;
								$rec['membership_type_id'] = $i;
								
								$table = $db->prefix . "_mem_type_access";
									
								$query = $db->GetInsertSQL($table, $rec, get_magic_quotes_gpc());
								$result = $db->Execute($query);
							endforeach;
						}
					}
					
					// Count events -----------------------------------
					$query = "
						SELECT COUNT(*) AS total_events
						FROM " . $db->prefix . "_event"
					;
					
					$result = $db->Execute($query);
					if (isset($result->fields)) {
						$total_events = $result->fields['total_events'];
						$result->Close();
					}
					else {
						$error_info = "file=evt_edit.php -- " . $query . " -- " . $this->db->ErrorMsg();
						$GLOBALS['am_error_log'][] = array('db_error', $error_info);
					}
					
					// insert statistics ------------------------------
					require_once('components/core/class/Statistic.class.php');
					$statistic = new Statistic($db, $event_config['statistic']);
					$statistic->module_id = $core_config['module_id']['event'];
					$statistic->item_id = $_SESSION['user_id'];
				
					// insert event statistics
					$statistic->statistic_type_id = $event_config['statistic']['total_events'];
					$statistic->setStatistic($total_events);
				}
			}
		}
		
		if (isset($_FILES['frm_file']) && !empty($_FILES['frm_file'])) {
			include_once('components/core/class/File.class.php');
				
			$file = new File($db, $core_config['file']);
			$file->max_height = $core_config['file']['image']['max_height'];
			$file->max_width = $core_config['file']['image']['max_width'];
			$file->module_id = 0; // there is no file-area for events, therefore we use core.
			$file->core_config_module = $core_config['module'];
			$file->user_id   = $_SESSION['user_id'];
			$file->setFile($_FILES['frm_file']);
					
			if (isset($_POST['frm_file_name']) && !empty($_POST['frm_file_name'])) {
				$file->setSaveName($_POST['frm_file_name']);
			}
			
			if ($file->checkAllocation()) {
				if ($file->checkMimeType()) {
					$file->moveFile();
					$file->createThumbNails();
					$file->insertRecord();
						
					if (isset($file->file_id)) {
						unset ($rec);
						$rec['file_id'] = $file->file_id;
							
						$query = "
							SELECT *
							FROM " . $db->prefix . "_event
							WHERE event_id=" . $event_id
						;
							
						$event_result = $db->Execute($query);
						
						if (isset($event_result->fields)) {
							$query = $db->GetUpdateSQL($event_result, $rec, false, get_magic_quotes_gpc());
							$result = $db->Execute($query);
						}
					}
				}
			}
		}
		
		if (empty($GLOBALS['am_error_log'])) { // everything was ok, send us to next page
		
			header("location: index.php?amn=evt_item&event_id=" . $event->event_id);
			exit;
		}
		
		$output_event = $_POST;
		$output_event['event_start_date'] = $_POST['schedule_start_date'];
		$output_event['event_start_time'] = $_POST['schedule_start_time'];
  		$output_event['event_body'] = stripslashes($output_event['event_body']);
		
		if (!empty($_POST['membership_types'])) {
			$output_event['membership_type_ids'] = $_POST['membership_types'];
		}
	}
	elseif (isset($_POST['sub_preview'])) {
		
		$output_event = $_POST;
		$output_event['event_start_date'] = $_POST['schedule_start_date'];
		$output_event['event_start_time'] = $_POST['schedule_start_time'];

		if (!empty($_POST['membership_types'])) {
			$output_event['membership_type_ids'] = $_POST['membership_types'];
		}
		
		$output_event['display_event_body'] = stripslashes(kses_parse($_POST['event_body'], 'max'));

		$output_event['event_body'] = stripslashes($output_event['event_body']);
		$output_event['display_event_body'] = stripslashes($output_event['display_event_body']);
		
		if ($core_config['xhtml_markup']['format']['nl2br'] == 1) {
			$output_event['display_event_body'] = nl2br($output_event['display_event_body']);
		}
		else {
			$output_event['display_event_body'] = $output_event['display_event_body'];
		}
	
		$body->set('event', $output_event);
	}
	else {
		$output_event['location_id'] = $_SESSION['location_id']; // pre-define location
	}
	
	// FILE SETUP
	require_once ("components/core/class/File.class.php");
	$file = new File($db, $core_config['file']);
	$file->user_id = $_SESSION['user_id'];
	$file->module_id = 0; // core
	$file->directory = "core";
	$file->no_image = $core_config['file']['image']['thumb'][2]['no_image'];
	$file->thumbs = $core_config['file']['image']['thumb'];
	
	$images = $file->selFiles("images", "t2");
	$body->set("images", $images);
	
	
	$body->set('event_config', $event_config);
	$body->set('event', $output_event);
}
else {
	header('location: index.php');
	exit;
}
?>
